<?php

namespace Drupal\l10n_pconfig\Form;

use Drupal\Core\Form\FormStateInterface;

/**
 * Alters the Drupal language module language forms.
 *
 * @package Drupal\l10n_pconfig\Form
 */
class PluralFormulaLanguageAddForm extends PluralFormulaLanguageFormBase {

  /**
   * Alters the configurable language entity edit and add form.
   *
   * @param array $form
   *   The form definition array for the configurable language entity.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function form(array &$form, FormStateInterface $form_state) {
    parent::form($form, $form_state);

    $form['predefined_submit']['#submit'][] = self::class . '::submitPredefinedLanguage';
    $form['custom_language']['submit']['#validate'][] = self::class . '::validateFormula';
  }

  /**
   * Predefined language, if we also know about the plural formula, set that too.
   */
  public static function submitPredefinedLanguage(array &$form, FormStateInterface $form_state) {
    $langcode = $form_state->getValue('predefined_langcode');
    $formulas = \Drupal::service('l10n_pconfig.drupalorg_plural_formula')->getDrupalPluralFormulae();
    if (isset($formulas[$langcode])) {
      self::updatePluralFormula($langcode, $formulas[$langcode]);
    }
    else {
      \Drupal::messenger()->addWarning(t('Plural formula cannot be automatically determined for the language added. Please <a href=":language-edit">edit the language</a> and specify the plural formula manually.', [':language-edit' => \Drupal::urlGenerator()->generateFromRoute('entity.configurable_language.edit_form', ['configurable_language' => $langcode])]));
    }
  }

}
